import {REST, Routes, ApplicationCommandOptionType} from 'discord.js';
import dotenv from 'dotenv';

dotenv.config();


// Note, command names must always be lower case
const commands = [
    {
        name: 'croak',
        description: 'Makes Sir Hornsworth Croak!',
    },
    {
        name: 'gear',
        description: 'Add or remove a gear to an employee',
        options: [
            {
                name: 'addremove',
                description: 'Do you want to add or remove a Gear?',
                type: ApplicationCommandOptionType.String,
                required: true,
            },
            {
                name: 'geartype',
                description: 'What sort of gear do you want to change?',
                type: ApplicationCommandOptionType.String,
                required: true,
            },
            {
                name: 'employee',
                description: 'From who?',
                type: ApplicationCommandOptionType.String,
                required: true,
            }
        ],
    },
    {
        name: 'employee',
        description: 'Hire or Fire an employee',
        options: [
            {
                name: 'hire-fire-promote',
                description: 'Hiring or Firing?',
                type: ApplicationCommandOptionType.String,
                required: true,
            },
            {
                name: 'employee-name',
                description: 'What is the character\'s name?',
                type: ApplicationCommandOptionType.String,
                required: true,
            },
        ],
    },
    {
        name: 'promote',
        description: 'Changes an employee\'s rank to the specified rank',
        options: [
            {
                name: 'employee-name',
                description: 'Who\'s rank are you changing?',
                type: ApplicationCommandOptionType.String,
                required: true,
            },
            {
                name: 'rank',
                description: 'which rank are you changing them to?',
                type:ApplicationCommandOptionType.String,
                required: true,
            }
        ]
    },
    {
        name: 'scoreboard',
        description: 'Related to the scoreboard',
        options: [
            {
                name: 'update-display',
                description: 'Displays the scoreboard or updates an already displayed one',
                type: ApplicationCommandOptionType.String,
                required: true,
            }
        ]
    },
];

const rest  = new REST({version: 10}).setToken(process.env.DISCORD_TOKEN);

(async ()=> {
    try {
        console.log('Registering slash commands...')
        await rest.put(
            Routes.applicationGuildCommands(process.env.CLIENT_ID, process.env.GUILD_ID), 
            {body: commands}
        )
        console.log('Slash Commands Registered.')
    } catch (error) {
        console.log(`There was an error: ${error}`);
    }
})();